clear all
set more off
set matsize 10000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"

set autotabgraphs on
local repbs = 1000

use "AnnualData.dta"


log using "logged_results/AdditionalResults", replace




* ================================================== *
* Section A.1 : occupations                          *
* ================================================== *


tempfile data1
save `data1'

keep if wave == 0

foreach x in 3 4 11 13 15 16 26 {
	
	egen _h1 = sum(jobs_o)
	egen _h2 = sum(jobs_o_`x')
	gen sh_o_`x' = _h2/_h1
	drop _h*
	
	egen _h1 = sum(jobs_i)
	egen _h2 = sum(jobs_i_`x')
	gen sh_i_`x' = _h2/_h1
	drop _h*
}

keep sh_* 
keep if _n == 1
gen id=1

reshape long sh_i_ sh_o_, i(id) j(bin) string
rename sh_*_ sh_*
drop id

gsort -sh_o 

replace bin = "Farmhand" if bin == "11"
replace bin = "Contractor, Carpenter" if bin == "13"
replace bin = "Teacher" if bin == "26"
replace bin = "Brick layer" if bin == "3"
replace bin = "Manufacturing" if bin == "16"
replace bin = "Maid/Helper" if bin == "15"
replace bin = "Cigar roller" if bin == "4"

egen to = sum(sh_o)
egen ti = sum(sh_i)

by bin, sort: sum sh_o sh_i

gsort -sh_o 


* ================================================== *
* Section A.2 : relative male wage graph             *
* ================================================== *
use `data1', clear

reg ttotal_male_nocross_wage i.Wave_number
predict _hold
gen err = ttotal_male_nocross_wage - _hold
gen Emale_nocross_wage = _b[_cons] + err
drop err _hold

reg ttotal_male_cross_wage i.Wave_number
predict _hold
gen err = ttotal_male_cross_wage - _hold
gen Emale_cross_wage = _b[_cons] + err
drop err _hold

sort Wave_number build
by Wave_number build: egen avg_male_cross_wage = mean(Emale_cross_wage)
by Wave_number build: egen avg_male_nocross_wage = mean(Emale_nocross_wage)
gen Emale_rel_wage1 = avg_male_cross_wage/avg_male_nocross_wage
drop avg_male_cross_wage avg_male_nocross_wage


#delimit ;
twoway(connected Emale_rel_wage wave if build == 0, lpattern(dash) lcolor(black) mcolor(black)) 
(connected Emale_rel_wage1 wave if build == 1, lcolor(black) mcolor(black)), 
graphregion(color(white) ilwidth(none)) xtitle("Period") xlabel(0(1)2) ylabel(1(0.1)1.6) 
legend(label(1 "No Build") label(2 "Build")) ytitle("") name(FigA2);
#delimit cr
graph export "graphs/Figure_A2.eps", as(eps) preview(off) replace


* ================================================== *
* Section A.3 : using current storage                *
* ================================================== *


local ylist "corn_store_rate bean_store_rate"

foreach x of local ylist {	

// Regressions
	display in red "---------------------------------------------"
	display in red "   Section A.3: direct measure of savings    "
	display in red "       outcome:  `x'	     			     "
	display in red "---------------------------------------------"
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build_agr build_noagr, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 			

}

* ================================================== *
* Section A.4 : output prices                        *
* ================================================== *

local ylist "tMaiz_saleprice tFrijoles_saleprice"

foreach x of local ylist {

display in red "---------------------------------------------"
display in red "   Section A.4: output price				 "
display in red "       outcome  `x'	     					 "
display in red "---------------------------------------------"

	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
}




* ================================================== *
* Section A.5 : land use and farming                 *
* ================================================== *


local ylist "ttotal_land tcrop_land land_outrent agr_hh"

foreach x of local ylist {

	
// Regressions

	display in red "---------------------------------------------"
	display in red "   Section A.5: land use	 			     "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 	

	
}

* ================================================== *
* Section A.6 : household size                       *
* ================================================== *

local ylist "HHsize Kids AdultMale AdultFemale"
foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Section A.6: Household size				 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_2 Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
	
}


* ================================================== *
* Section A.7 : ihs specifications                   *
* ================================================== *


local ylist "ttotal_earnings ttotal_cross_earnings ttotal_nocross_earnings tintermed_spend tfert_spend tpest_spend tfarmprofit1b tfarmprofit2b"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Section A.7: IHS for main specifications	 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	capture drop ihs_`x'
	qui gen ihs_`x' = ln(`x' + ((`x'^2+1)^.5))
	
	cgmwildboot ihs_`x' Wave_2 Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway ihs_`x' comm
	
}



* ================================================== *
* Section A.8 : planting decisions                   *
* ================================================== *

local ylist "Maiz_anyplant Frijoles_anyplant Coffee_anyplant"

foreach x of local ylist {


// Regressions
	display in red "---------------------------------------------"
	display in red "   Section A.8: planting decisions			 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 			

}



* ================================================== *
* Section A.9 : other savings vehicles               *
* ================================================== *

local ylist "Ibuy_pig Ibuy_cow Ibuy_goat tbusiness_debt tother_debt thh_totalspend"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Section A.9: other savings       		 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"

	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 	
}



* ================================================== *
* Section A.10 : directly asking about bridge        *
* ================================================== *

display in red "---------------------------------------------"
display in red "   Section A.10: qual response on bridges	 "
display in red "       outcome: cope with floods?			 "
display in red "---------------------------------------------"


// This is Table 9 "How do you cope with a flood?
tab flood_how if build == 0 & Wave_number == 4
tab flood_how if build == 1 & Wave_number == 4


display in red "---------------------------------------------"
display in red "   Section A.10: qual response on bridges	 "
display in red "       outcome: how do you use bridge?		 "
display in red "---------------------------------------------"

	
// This is Table 10 "If you use a bridge, what do you use it for?"
tab bridge_work if build == 1 & flood_how == "Bridge" & Wave_number == 4
tab bridge_buy if build == 1 & flood_how == "Bridge" & Wave_number == 4
tab bridge_school if build == 1 & flood_how == "Bridge" & Wave_number == 4
tab bridge_hospital if build == 1 & flood_how == "Bridge" & Wave_number == 4
tab bridge_sell if build == 1 & flood_how == "Bridge" & Wave_number == 4



* ================================================== *
* Section A.11 : effects on market income, by period *
* ================================================== *

#delimit ;
local ylist "
ttotal_earnings ttotal_cross_earnings ttotal_nocross_earnings
tintermed_spend tfert_spend tpest_spend
tMaiz_harvest tMaiz_yield tFrijoles_harvest tFrijoles_yield tfarmprofit2b
corn_store2_rate bean_store2_rate
";
#delimit cr



forvalues ii = 3/4 {
	foreach x of local ylist {

		display in red "---------------------------------------------"
		display in red "       Section A.11: Per-Period Results      "
		display in red "       outcome = `x', period = `ii'			 "
		display in red "---------------------------------------------"
		
		cgmwildboot `x' Wave_2 Wave_`ii' Comm_* build2 if (Wave_number == 2 | Wave_number == `ii'), cluster(comm) bootcluster(comm) reps(`repbs')
		loneway `x' comm if (Wave_number == 2 | Wave_number == `ii') 				
		
	}
}




log close
translate "logged_results/AdditionalResults.smcl" "logged_results/AdditionalResults.pdf", replace
erase "logged_results/AdditionalResults.smcl"

