clear all
set more off
set matsize 10000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"

set autotabgraphs on
local repbs = 1000

use "AnnualData.dta"

* ------------------------------------ *
* Figures created here,  			   *
* regression tables below 			   *
* ------------------------------------ *


* Figure 2: Intermediate inputs

#delimit ;
twoway(kdensity lintermed_spend if build2 == 0,lpattern(--) lcolor(black)) 
(kdensity lintermed_spend if build2 == 1, lcolor(black)), 
ytitle("") xtitle("Log Intermediate Expenditures (C$)") graphregion(color(white) ilwidth(none)) name(Fig2) 
legend(label(1 "No Bridge") label(2 "Bridge"));
#delimit cr
graph export "graphs/Figure2.eps", as(eps) preview(off) replace






log using "logged_results/MainRegs_Annual", replace



* ============================================= *
* Table 1 avg male earnings/avg female earnings *
* ============================================= *

sum ttotal_male_earnings if Wave_2 == 1
sum ttotal_female_earnings if Wave_2 == 1


* ================= *
* Table 2 (balance) *
* ================= *

// Distance to nearest town
by comm Wave_2, sort: gen counter = _n
reg dist_markettown build if Wave_2 == 1 & counter == 1
drop counter

// (flooding intensity in HF code)


// Household composition

reg bridge_dist_km build if Wave_2 == 1
reg age_head build if Wave_2 == 1
reg edu_head build if Wave_2 == 1
reg Kids build if Wave_2 == 1
reg HHsize build if Wave_2 == 1

// Occupation and Earnings
reg agr_hh build if Wave_2 == 1
reg wage_hh build if Wave_2 == 1
reg ttotal_earnings build if Wave_2 == 1 
reg ttotal_male_nocross_wage build if Wave_2 == 1 
reg ttotal_male_cross_wage build if Wave_2 == 1 

// Farming
reg tMaiz_harvest build if Wave_2 == 1 
reg tFrijoles_harvest build if Wave_2 == 1 
reg tMaiz_saleprice build if Wave_2 == 1  
reg tFrijoles_saleprice build if Wave_2 == 1 
reg Staples_anyplant build if Wave_2 == 1
reg tintermed_spend build if Wave_2 == 1


* Does not include: sales price for maize, sales price for frijoles since not defined over all households.
reg build bridge_dist age_head edu_head Kids HHsize agr_hh wage_hh ttotal_earnings ttotal_male_nocross_earnings ttotal_male_cross_earnings tMaiz_harvest tFrijoles_harvest Staples_anyplant tintermed_spend if Wave_2 == 1
probit build bridge_dist age_head edu_head Kids HHsize agr_hh wage_hh ttotal_earnings ttotal_male_nocross_earnings ttotal_male_cross_earnings tMaiz_harvest tFrijoles_harvest Staples_anyplant tintermed_spend if Wave_2 == 1



* ================================ *
* Table 3/4 (HF -- different code) *
* ================================ *


* ============================ *
* Table 4 - earnings           *
* ============================ *


local ylist "ttotal_earnings ttotal_cross_earnings ttotal_nocross_earnings ttotal_male_earnings ttotal_male_cross_earnings ttotal_male_nocross_earnings ttotal_female_earnings ttotal_female_cross_earnings ttotal_female_nocross_earnings"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Table 4: Earnings   						 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_2 Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
}







* =================================== *
* Table 5 - decomposing earnings      *
* =================================== *


* ------------------------- PANEL A: MEN ----------------------- *


local ylist "total_I_male_earnings total_I_male_cross_earnings total_I_male_nocross_earnings ttotal_male_cross_wage ttotal_male_nocross_wage ttotal_male_cross_days ttotal_male_nocross_days"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Table 5a: Male Earnings   						 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_2 Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
	
}


* ------------------------- PANEL B: WOMEN ----------------------- *


local ylist "total_I_female_earnings total_I_female_cross_earnings total_I_female_nocross_earnings ttotal_female_cross_wage ttotal_female_nocross_wage ttotal_female_cross_days ttotal_female_nocross_days"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Table 5b: Female Earnings   						 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_2 Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
	
}







* ================================ *
* Table 6 : farm impact            *
* ================================ *


// Input expenditures (Panels A and B)

local ylist "tintermed_spend tfert_spend tpest_spend"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "   Table 6: Farm investment	(panels A+B)	 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build_agr build_noagr, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 

}



// Farm Output (Panels A and B)

local ylist "tMaiz_harvest tMaiz_yield tFrijoles_harvest tFrijoles_yield tfarmprofit1b tfarmprofit2b"

foreach x of local ylist {


	display in red "---------------------------------------------"
	display in red "   Table 6: Yield and Harvest (panels A+B) 	 "
	display in red "       outcome = `x'	     				 "
	display in red "---------------------------------------------"

	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build_agr build_noagr, cluster(comm) bootcluster(comm) reps(`repbs')	
	loneway `x' comm 

		
}


* ================================= *
* Table 7 : farm saving decisions   *
* ================================= *
local ylist "corn_store2_rate bean_store2_rate"

foreach x of local ylist {

	display in red "---------------------------------------------"
	display in red "       Table 7: Storage		     	     "
	display in red "       crop = `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
	cgmwildboot `x' Wave_3 Wave_4 Comm_* build_agr build_noagr, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 	

	
}

* ============================= *
* Table 8 : heterogeneity       *
* ============================= *

cgmwildboot ihs_intermed_spend Wave_3 Wave_4 Comm_* build2, cluster(comm) bootcluster(comm) reps(`repbs')
cgmwildboot ihs_intermed_spend Wave_3 Wave_4 Comm_* build2 ihs_C_total_b build_C, cluster(comm) bootcluster(comm) reps(`repbs')
cgmwildboot ihs_intermed_spend Wave_3 Wave_4 Comm_* build2 norm_dist build_dist, cluster(comm) bootcluster(comm) reps(`repbs')
cgmwildboot ihs_intermed_spend Wave_3 Wave_4 Comm_* build2 norm_dist ihs_C_total_b build_C build_dist, cluster(comm) bootcluster(comm) reps(`repbs')
cgmwildboot ihs_intermed_spend Wave_3 Wave_4 Comm_* build2 ihs_C_total_b build_C log_dist build_ldist, cluster(comm) bootcluster(comm) reps(`repbs')

loneway ihs_intermed_spend comm



log close
translate "logged_results/MainRegs_Annual.smcl" "logged_results/MainRegs_Annual.pdf", replace
erase "logged_results/MainRegs_Annual.smcl"

