clear all
set more off
set matsize 10000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"

local repbs = 1000
use  "HFData.dta", clear
xtset id week


tempfile data1
save `data1'


log using "logged_results/MainRegs_HF", replace



* ============================================= *
* Figure 1 -- Income realizations and flooding  *
* ============================================= *

#delimit ;
twoway(kdensity income if flood == 0, lpattern(dash) lcolor(black))
(kdensity income if flood == 1, lcolor(black)) 
if bridge == 0 & income <= 4000,
ylabel(0(0.0002)0.001) yscale(r(0 0.001)) xscale(r(0 4000)) xlabel(0(1000)4000) 
legend(label(1 "No flood") label(2 "Flood")) 
name(Figure1a)  xtitle("Income (C$)") ytitle("") graphregion(color(white) ilwidth(none))
;
#delimit cr
graph export "graphs/Figure1a.eps", as(eps) preview(off) replace




#delimit ;
twoway(kdensity income if flood == 0, lpattern(dash) lcolor(black))
(kdensity income if flood == 1,lcolor(black)) 
if bridge == 1 & income <= 4000, 
ylabel(0(0.0002)0.001) yscale(r(0 0.001)) xscale(r(0 4000)) xlabel(0(1000)4000) 
legend(label(1 "No flood") label(2 "Flood")) 
name(Figure2b)  xtitle("Income (C$)") ytitle("")  graphregion(color(white) ilwidth(none)) 
;
#delimit cr
graph export "graphs/Figure1b.eps", as(eps) preview(off) replace




* =========================================================== *
* Table 1   -- baseline income last week				      *
* =========================================================== *

* income recorded for 2 weeks. /2 to get weekly income. Same as LSMS
gen i2 = income/2
sum i2 if week <= 25




* =========================================================== *
* Table 2   -- "Flooding intensity" panel of balance check    *
* =========================================================== *

tostring(week community), replace
gen ID = community + "--" + week
sort ID
drop if ID[_n] == ID[_n-1]
destring(week), replace
sort community week
drop ID
destring(community), replace


reg flood_days bridge_eventual if week <= 25
reg flood bridge_eventual if week <= 25
reg flood_days bridge_eventual if week <= 25 & flood == 1




* ============================================= *
* Table 3   -- Effect of flooding on income     *
* ============================================= *

use `data1', clear
sort id week

gen interact = bridge * flood
gen bridge_lag = L2.bridge
gen flood_lag = L2.flood
gen interact_lag = bridge_lag * flood_lag



local ylist "tincome no_inc"

foreach x of local ylist {


	quietly {
	
	// De-meaned dep variables
		gen _hold = `x' if !missing(`x')
		by id: egen avg_1 = mean(_hold)
		gen `x'_net = `x' - avg_1
		drop avg_1 _hold

		
	// Regressions For First Part: Do floods cause earnings drops?
		gen _hold = bridge if !missing(`x')
		gen _hold0 = bridge_flood if !missing(`x')
		
		by id: egen _hold5 = mean(_hold)
		by id: egen _hold50 = mean(_hold0)
			
		gen bridge_n = bridge - _hold5
		gen bridge_flood_n = bridge_flood - _hold50
		drop _hold*
		
		
	// Regressions For Second Part: Interaction Terms + Lags
		
		gen _hold = bridge_lag if !missing(`x')
		gen _hold0 = flood_lag if !missing(`x')
		gen _hold00 = interact_lag if !missing(`x')
		
		* bridge is already defined above
		gen _hold11 = flood if !missing(`x')
		gen _hold111 = interact if !missing(`x')
		
		by id: egen _hold5 = mean(_hold)
		by id: egen _hold50 = mean(_hold0)
		by id: egen _hold500 = mean(_hold00)

		by id: egen _hold60 = mean(_hold11)
		by id: egen _hold600 = mean(_hold111)
		
		gen bridge_lag_n = bridge_lag - _hold5
		gen flood_lag_n = flood_lag - _hold50
		gen interact_lag_n = interact_lag - _hold500		
		
		gen flood_n = flood - _hold60
		gen interact_n = interact - _hold600				

		drop _hold*
		
		
		
	// normalized week indicators
		forvalues ii = 5/71 {
			gen _hold1 = 0
			replace _hold1 = 1 if week == `ii'
		
			gen _hold = _hold1 if !missing(`x')
			by id: egen _hold2 = mean(_hold)
			gen Week_`ii'_n = _hold1 - _hold2
			drop _hold _hold1 _hold2
		}
		
	}
	
// Regression

	display in red "---------------------------------------------"
	display in red "   Earnings w/ lags: outcome `x'				 	 " 
	display in red "   Table 3   				     			 "
	display in red "---------------------------------------------"	
	
	cgmwildboot `x'_net Week_*_n bridge_n flood_n interact_n, cluster(comm) bootcluster(comm) reps(`repbs')
	cgmwildboot `x'_net Week_*_n bridge_n flood_n interact_n bridge_lag_n flood_lag_n interact_lag_n, cluster(comm) bootcluster(comm) reps(`repbs')
	
	loneway `x' comm 

	
// Drop
	drop Week_*_n bridge_n bridge_flood_n flood_n interact_n bridge_lag_n flood_lag_n interact_lag_n	
	drop `x'_net
}




log close
translate "logged_results/MainRegs_HF.smcl" "logged_results/MainRegs_HF.pdf", replace
erase "logged_results/MainRegs_HF.smcl"







