clear all
set more off
set matsize 11000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"


use "AnnualData.dta"
rename Wave_number wavenumber

tempfile data1 
save `data1'


// creates local macro that includes every 6-number combination (i.e., every treatment possibility)
// This tells you how many different treatment effects you have to run.

tuples 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15, min(6) max(6) display
local num_rand = `ntuples'

// The total list of dependent variables you want to run
#delimit ;
local ylist "
ttotal_earnings ttotal_cross_earnings ttotal_nocross_earnings
tintermed_spend tfert_spend tpest_spend
tMaiz_harvest tMaiz_yield tFrijoles_harvest tFrijoles_yield tfarmprofit2b
corn_store2_rate bean_store2_rate
";
#delimit cr

local num_dep : word count `ylist'



// Display things before starting
display in red "Number of dependent variables considered: `num_dep'"
display in red "Number of placebos per dep variable: `num_rand'"



// Set up matrix to collect data: number of columns is number of regressions.
// Number of rows is 1 (true value) + number of placebos.
matrix RI = J(`num_rand',`num_dep'+1,.)

local matnames "`ylist' randomization"
matrix colnames RI = `matnames'
	
			

* ----------------------------------------------- *
*        compute placebo treatment effects        *
* ----------------------------------------------- *
 

quietly {



// For each dependent variable
	local county = 1
	foreach y of local ylist {

	
	// All combinations of possible treatment across villages.
	// includes all possible placebos and the true realization.
			local count = 1
			forvalues i = 1/`num_rand' {
			
			display in red "dep var: `county' of `num_dep'...loop: `count'"
						
				use `data1', clear

				* randomization for this loop
				gen RealBuild = "`tuple`i''"
				split RealBuild, gen(RB_)
				destring(RB_*), replace
				
				* need to keep track of what the randomization is.
				gen test = subinstr(RealBuild," ","",.) 
				destring(test), replace
				sum test
				matrix RI[`count',`num_dep'+1] = r(max)			
				
				* construct the treatment variable.
				gen build2_cf = 0
				forvalues jj = 1/6 {
					replace build2_cf = 1 if comm == RB_`jj' & wavenumber >= 3 & !missing(wavenumber)
				}
				
				* run regression and store results.
				reg `y' build2_cf i.wavenumber i.comm
				matrix RI[`count',`county'] = _b[build2_cf]

				local count = `count' + 1
			}
		local county = `county' + 1
	}
	
	
	
}

putexcel set RandomInf.xlsx, replace 
putexcel A1 = matrix(RI), colnames




	
	
	
	
* ----------------------------------------------- *
*        compute exact p-values                   *
* ----------------------------------------------- *

import excel "RandomInf.xlsx", sheet("Sheet1") firstrow clear


quietly {
	matrix CDFT = J(`num_dep',1,.)
	matrix rownames CDFT = `ylist' 

	* this is the true treatment effect: villages 1,2,5,9,12,13 are treated.
	gen true = 0 
	replace true = 1 if randomization == 12591213
	
	local county = 1
	foreach y of local ylist {
	
		display in red "Computing exact p values... dep var: `county' of `num_dep'"

		gen abs_`y' = abs(`y')
		sort abs_`y'
		gen _hold = (`num_rand'+1-_n)/`num_rand' if true == 1		
		sum _hold
		matrix CDFT[`county',1] = r(max)
		
		local county = `county' + 1
		drop _hold
	}


	matrix list CDFT
	putexcel set RandomInf_CDF.xlsx, replace 
	putexcel A1 = matrix(CDFT), rownames
}
			
			
			
			
