clear all
set more off
set matsize 10000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"

local repbs = 1000

use "AnnualData.dta"
sort id

log using "logged_results/SuppA2_HHfe", replace


* -------------- earnings panel 
#delimit ;
local ylist "
ttotal_earnings ttotal_cross_earnings ttotal_nocross_earnings 
";
#delimit cr

foreach x of local ylist {


	quietly {
	// De-meaned dep variables
		by id: egen avg_1 = mean(`x')
		gen `x'_net = `x' - avg_1
		drop avg_1


	// Build indicators
		gen _hold = build2 if !missing(`x')
		by id: egen _hold5 = mean(_hold)
		gen build_n = build2 - _hold5
		
	// Wave indicators		
		gen _hold2 = Wave_2 if !missing(`x')
		gen _hold3 = Wave_3 if !missing(`x')
		gen _hold4 = Wave_4 if !missing(`x')
		
		by id: egen _hold6 = mean(_hold2)
		by id: egen _hold7 = mean(_hold3)
		by id: egen _hold8 = mean(_hold4)

		gen Wave_2n = Wave_2 - _hold6
		gen Wave_3n = Wave_3 - _hold7
		gen Wave_4n = Wave_4 - _hold8

	}	
	
// Regressions	

	display in red "---------------------------------------------"
	display in red "   Earnings   								 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x'_net Wave_2n Wave_3n Wave_4n build_n, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 

	
// Drop
	drop Wave_2n Wave_3n Wave_4n build_n 
	drop `x'_net
	drop _hold*
	
	
}


* ------------ farm expenditure panel

local ylist "tintermed_spend tfert_spend tpest_spend"

foreach x of local ylist {

	quietly {

	// De-meaned dep variables
		by id: egen avg_1 = mean(`x')
		gen `x'_net = `x' - avg_1
		drop avg_1

	// Build indicators
		gen _hold = build2 if !missing(`x')
		by id: egen _hold5 = mean(_hold)
		gen buildn = build2 - _hold5

		
	// Wave indicators		
		gen _hold2 = Wave_2 if !missing(`x')
		gen _hold3 = Wave_3 if !missing(`x')
		gen _hold4 = Wave_4 if !missing(`x')
		
		by id: egen _hold6 = mean(_hold2)
		by id: egen _hold7 = mean(_hold3)
		by id: egen _hold8 = mean(_hold4)

		gen Wave_2n = Wave_2 - _hold6
		gen Wave_3n = Wave_3 - _hold7
		gen Wave_4n = Wave_4 - _hold8
	}	

// Regressions

	display in red "---------------------------------------------"
	display in red "   Table 4: Farm investment					 "
	display in red "       outcome  `x'	     					 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x'_net Wave_2n Wave_3n Wave_4n buildn, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
	
// Drop
	drop Wave_2n Wave_3n Wave_4n buildn 
	drop `x'_net
	drop _hold*
}



* ----------------- farm outcomes panel

local ylist "tMaiz_harvest tMaiz_yield tFrijoles_harvest tFrijoles_yield tfarmprofit2b"

foreach x of local ylist {


	quietly {
	// De-meaned dep variables
		by id: egen avg_1 = mean(`x')
		gen `x'_net = `x' - avg_1
		drop avg_1

	// Build indicators
		gen _hold = build2 if !missing(`x')
		by id: egen _hold5 = mean(_hold)
		gen build_n = build2 - _hold5

	// Wave indicators		
		gen _hold2 = Wave_2 if !missing(`x')
		gen _hold3 = Wave_3 if !missing(`x')
		gen _hold4 = Wave_4 if !missing(`x')
		
		by id: egen _hold6 = mean(_hold2)
		by id: egen _hold7 = mean(_hold3)
		by id: egen _hold8 = mean(_hold4)

		gen Wave_2n = Wave_2 - _hold6
		gen Wave_3n = Wave_3 - _hold7
		gen Wave_4n = Wave_4 - _hold8
	}	

// Regressions

	display in red "---------------------------------------------"
	display in red "   Table 5: Yield and Harvest 		     	 "
	display in red "       outcome = `x'	     				 "
	display in red "---------------------------------------------"

	cgmwildboot `x'_net Wave_2n Wave_3n Wave_4n build_n, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 
	
// Drop
	drop Wave_2n Wave_3n Wave_4n build_n 
	drop `x'_net
	drop _hold*
		
}


* -------------------- savings panel

local ylist "corn_store2_rate bean_store2_rate"

foreach x of local ylist {


	quietly {
	
	// De-meaned dep variables
		by id: egen avg_1 = mean(`x')
		gen `x'_net = `x' - avg_1
		drop avg_1

	// Build indicators
		gen _hold = build2 if !missing(`x')
		by id: egen _hold5 = mean(_hold)
		gen buildn = build2 - _hold5
		
	// Wave indicators		
		gen _hold2 = Wave_2 if !missing(`x')
		gen _hold3 = Wave_3 if !missing(`x')
		gen _hold4 = Wave_4 if !missing(`x')
		
		by id: egen _hold6 = mean(_hold2)
		by id: egen _hold7 = mean(_hold3)
		by id: egen _hold8 = mean(_hold4)

		gen Wave_2n = Wave_2 - _hold6
		gen Wave_3n = Wave_3 - _hold7
		gen Wave_4n = Wave_4 - _hold8
	}
	
// Regressions

	display in red "---------------------------------------------"
	display in red "       Table 10: Storage		     	     "
	display in red "       crop = `x'	     					 "
	display in red "---------------------------------------------"
	cgmwildboot `x'_net Wave_2n Wave_3n Wave_4n buildn, cluster(comm) bootcluster(comm) reps(`repbs')
	loneway `x' comm 	
	
// Drop
	drop Wave_2n Wave_3n Wave_4n buildn 
	drop `x'_net
	drop _hold*

	
}


log close
translate "logged_results/SuppA2_HHfe.smcl" "logged_results/SuppA2_HHfe.pdf", replace
erase "logged_results/SuppA2_HHfe.smcl"


