clear all
set more off
set matsize 10000
set maxvar 32500
cd "C:\Users\kmd86\Desktop\Papers I'm Working On\Nicaragua Bridges\Submission_Econometrica\BrooksDonovan_ECMA_SubmitAccepted\Additional Online Material\empirics_code\"

local color_green_bar "132 186 91"
local repbs = 1000


use  "HFData.dta", clear
xtset id week
sort id week

gen bridge_lag = L2.bridge
gen flood_lag = L2.flood
gen interact_lag = bridge_lag * flood_lag
gen interact = bridge * flood

tostring(community), replace

tempfile data1 
save `data1'


log using "logged_results/SuppB", replace


* ---------------------------------------------------- *
* Supp B.1: Importance of labor market income          *
* ---------------------------------------------------- *

sort id
by id: gen total_count = _N

gen test = 1 if income > 0 & !missing(income)
by id: egen total_income_count = sum(test)
drop test
gen sh_income = total_income_count/total_count

hist sh_income, width(0.05) name(SuppB_Fig1a) fraction  /*
*/ xtitle("Fraction of weeks with positive wage earnings") ytitle("Fraction of Households") /*
*/ yscale(r(0 0.35)) ylabel(0(0.10)0.35) /*
*/ graphregion(color(white)  ilwidth(none)) bgcolor(white) lcolor(black) fcolor("`color_green_bar'")
graph export "graphs/SuppB_Figure1a.eps", as(eps) preview(off) replace

hist sh_income if total_count >= 10, width(0.05) name(SuppB_Fig1b) fraction  /*
*/ xtitle("Fraction of weeks with positive wage earnings") ytitle("Fraction of Households") /*
*/ yscale(r(0 0.35)) ylabel(0(0.10)0.35) /*
*/ graphregion(color(white)  ilwidth(none)) bgcolor(white) lcolor(black) fcolor("`color_green_bar'")
graph export "graphs/SuppB_Figure1b.eps", as(eps) preview(off) replace




* ---------------------------------------------------- *
* Supp B.2: How responses change during floods         *
* ---------------------------------------------------- *


// Figure 2 -- obs per household
hist total_count, width(1) name(SuppB_Fig2) fraction  /*
*/ xtitle("No. of observations") ytitle("Fraction of Households") /*
*/ yscale(r(0 0.08)) ylabel(0(0.02)0.08) /*
*/ graphregion(color(white) ilwidth(none)) bgcolor(white) lcolor(black) fcolor("`color_green_bar'")
graph export "graphs/SuppB_Figure2.eps", as(eps) preview(off) replace




// Figure 3 -- obs per household assuming all missing are zeros.
use "HFData_Balanced.dta", clear
tostring(community), replace

gen HAS_DATA = 0
replace HAS_DATA = 1 if community != ""
by id,sort: egen total_count = sum(HAS_DATA)

forvalues ii = 5/71 {
	gen Week_`ii' = 0
	replace Week_`ii' = 1 if week == `ii'
}

sort id
by id: gen total_count_all = _N

gen test = 1 if income > 0 & !missing(income)
by id: egen total_income_count_all = sum(test)
drop test

gen sh_income_all = total_income_count_all/total_count_all

hist sh_income_all, width(0.05) name(SuppB_Fig3a) fraction  /*
*/ xtitle("Fraction of weeks with positive wage earnings") ytitle("Fraction of Households") /*
*/ yscale(r(0 0.35)) ylabel(0(0.10)0.35) /*
*/ graphregion(color(white)  ilwidth(none)) bgcolor(white) lcolor(black) fcolor("`color_green_bar'")
graph export "graphs/SuppB_Figure3a.eps", as(eps) preview(off) replace

hist sh_income_all if total_count >= 10, width(0.05) name(SuppB_Fig3b) fraction  /*
*/ xtitle("Fraction of weeks with positive wage earnings") ytitle("Fraction of Households") /*
*/ yscale(r(0 0.35)) ylabel(0(0.10)0.35) /*
*/ graphregion(color(white)  ilwidth(none)) bgcolor(white) lcolor(black) fcolor("`color_green_bar'")
graph export "graphs/SuppB_Figure3b.eps", as(eps) preview(off) replace


// Table 3: Effect of flooding on survey response
by week comm, sort: egen flood2 = max(flood)

gen answer = 0
replace answer = 1 if !missing(no_inc)


sort id 
local ylist "answer"
foreach x of local ylist {

	quietly {
	
	// De-meaned dep variables
		gen _hold = `x' if !missing(`x')
		by id: egen avg_1 = mean(_hold)
		gen `x'_net = `x' - avg_1
		drop avg_1 _hold

		
	// Normalize flood realization
		gen _hold = flood2 if !missing(`x')
		by id: egen _hold5 = mean(_hold)
		gen flood_n = flood2 - _hold5
		drop _hold
		
	// Week indicators
		forvalues ii = 5/71 {
			gen _hold = Week_`ii' if !missing(`x')
			by id: egen _hold2 = mean(_hold)
			gen Week_`ii'_n = Week_`ii' - _hold2
			drop _hold _hold2
		}
		
	}
	
// Regressions	

	display in red "---------------------------------------------"
	display in red "   Flood and answering: SuppB Table 3  		 " 
	display in red "   No Week FE 				     			 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x'_net flood_n, cluster(comm) bootcluster(comm) reps(`repbs')
	
	display in red "---------------------------------------------"
	display in red "   Flood and answering: SuppB Table 3  		 " 
	display in red "   With Week FE 				     		 "
	display in red "---------------------------------------------"
	
	cgmwildboot `x'_net Week_*_n flood_n, cluster(comm) bootcluster(comm) reps(`repbs')
	
	loneway `x' comm 

	
// Drop
	drop Week_*_n flood_n _hold*
	drop `x'_net
}




* ---------------------------------------------------- *
* Supp B.4: HF Balance checks                          *
* ---------------------------------------------------- *

use `data1', clear

xtset id week
gen month = month(date)
order month, after(date)
sort date

by id, sort: egen hf_count = count(no_inc)
keep id hf_count

sort id 
drop if id[_n] == id[_n-1]

tempfile data55
save `data55'


use "AnnualData.dta", clear
keep if Wave_number == 2
order id

#delimit ;
keep id build
bridge_dist age_head Kids edu_head HHsize 
agr_hh wage_hh ttotal_earnings 
tMaiz_harvest tFrijoles_harvest  Maiz_anyplant Frijoles_anyplant tintermed_spend 
Staples_anyplant I_intermed
;
#delimit cr

merge 1:1 id using `data55'

order _merge
sort _merge id
keep if _merge == 1 | _merge == 3
replace hf_count = 0 if _merge == 1
drop _merge

gen in_HF = 0
replace in_HF = 1 if hf_count > 0
gen build_HF = build*in_HF
gen build_HF_num = build*hf_count



* ------------ Table 4. Outcome is number of observations.

// Household composition
reg bridge_dist build hf_count build_HF_num
reg age_head build hf_count build_HF_num
reg edu_head build hf_count build_HF_num
reg Kids build hf_count build_HF_num
reg HHsize build hf_count build_HF_num 

// Occupation and Earnings
reg agr_hh build hf_count build_HF_num
reg wage_hh build hf_count build_HF_num
reg ttotal_earnings build hf_count build_HF_num 

// Farming
reg tMaiz_harvest build hf_count build_HF_num 
reg tFrijoles_harvest build hf_count build_HF_num
reg Staples_anyplant build hf_count build_HF_num
reg tintermed_spend build hf_count build_HF_num 
reg I_intermed build hf_count build_HF_num






* -------------- Actual Table 5. Outcome is indicator for participation.

// Household composition
reg bridge_dist build in_HF build_HF
reg age_head build in_HF build_HF 
reg Kids build in_HF build_HF 
reg edu_head build in_HF build_HF 
reg HHsize build in_HF build_HF 

// Occupation and Earnings
reg agr_hh build in_HF build_HF 
reg wage_hh build in_HF build_HF 
reg ttotal_earnings build in_HF build_HF  

// Farming
reg tMaiz_harvest build in_HF build_HF  
reg tFrijoles_harvest build in_HF build_HF 
reg Staples_anyplant build in_HF build_HF 
reg tintermed_spend build in_HF build_HF 
reg I_intermed build in_HF build_HF 








* ---------------------------------------------------- *
* Supp B.5: rainfall and flooding                      *
* ---------------------------------------------------- *

use "HFData.dta", clear
merge m:1 community week using "RainData.dta"

keep if _merge == 3
drop _merge

* one data-point per week-village

tostring(week community), replace
gen ID = community + "--" + week
sort ID
drop if ID[_n] == ID[_n-1]
destring(week), replace
sort community week
drop ID

keep community week flood flood_days rain mean_rain sd_rain bridge_eventual 
encode(community), gen(ccode)

gen z_rain = (rain - mean_rain)/sd_rain

gen lrain = ln(rain)
gen rain2sig = 0
replace rain2sig = 1 if rain > mean_rain + 2*sd_rain



xtset ccode week

xtreg flood rain, fe 
xtreg flood z_rain, fe 
xtreg flood rain2sig, fe

xtreg flood_days rain, fe
xtreg flood_days z_rain, fe 
xtreg flood_days rain2sig, fe 



log close
translate "logged_results/SuppB.smcl" "logged_results/SuppB.pdf", replace
erase "logged_results/SuppB.smcl"







